DataTables example - Custom data source property

# DataTables example Custom data source property

When loading data from an Ajax source, by default, DataTables will look for the data to use in the `data` parameter of a returned object (e.g. `{ "data": [...] }`). This can easily be change by using the `dataSrc` option of the `ajaxDT` initiation option.

The `ajax.dataSrcDT` has a number of ways in which it can be used:

- As a string (e.g. `dataSrc: 'myData'`) - obtain data from a different property in the source object.
- As an empty string (e.g. `dataSrc: ''`) - the data source is not an object but an array.
- As a function (e.g. `dataSrc: function(json) {}`) - a function can be used to transform the data from one source format to another (for example you could convert from XML to a Javascript object). The value returned from the function is used as the data for the table.

The example below shows `ajax.dataSrcDT` being used as a string to get the data from a different source property, in this case `demo` but it could be any value, included a nested property by using standard dotted Javascript object notation.

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').dataTable( { "ajax": { "url": "data/arrays_custom_prop.txt", "dataSrc": "demo" } } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.